all_resource_names

Function all_resource_names 

pub fn all_resource_names(sds: &[StructureDefinition]) -> HashSet<String>
Returns the set of resource type names from the given [StructureDefinition]s. Useful for getting the full unfiltered set when no CapabilityStatement filtering is desired.